HasData

Trait HasData 

pub trait HasData {
    type Item;
}
A trait for iterable collections which contain data of a given type.

In most cases, you shouldn’t implement this trait directly; instead, you should implement IntoIterator, which will in turn implement this trait.

The only exception is dynamically-sized types, which cannot implement IntoIterator. Instead, you should implement this trait to indicate what type of data is inside the collection.

Required Associated Types

type Item

The type of the data inside this collection.

Implementations on Foreign Types

Source

impl<T> HasData for [T]

Source

type Item = T

Implementors