pub trait Iter<'a>: 'a + HasData {
type ItemRef: Ref<'a, Self::Item>;
type IterRef: Iterator<Item = Self::ItemRef>;
// Required method
fn iter(&'a self) -> Self::IterRef;
}Expand description
A trait for collections which can be iterated by reference.
In most cases, you shouldn’t implement this trait directly; instead, you should implement
IntoIterator for a reference of this type, which will in turn implement this trait.