MapIterMut

Trait MapIterMut 

pub trait MapIterMut<'a>: MapIter<'a> + IterMut<'a> {
    type ValueMut: RefMut<'a, Self::Value>;
    type IterValuesMut: Iterator<Item = Self::ValueMut>;

    // Required method
    fn values_mut(&'a mut self) -> Self::IterValuesMut;
}
A trait for map-like collections which can be iterated by references to keys, and mutable references to values.

Required Associated Types

type ValueMut: RefMut<'a, Self::Value>

Type of the mutable references to the values in the collection.

For more information, see the ValueRefMut trait.

type IterValuesMut: Iterator<Item = Self::ValueMut>

Type of the iterator over mutable references to values.

Required Methods

fn values_mut(&'a mut self) -> Self::IterValuesMut

Constructs an iterator over mutable references to the values in this collection.

Implementations on Foreign Types

Source

impl<'a, K: 'a + Ord, V: 'a> MapIterMut<'a> for BTreeMap<K, V>

Source

type ValueMut = &'a mut V

Source

type IterValuesMut = ValuesMut<'a, K, V>

Source

fn values_mut(&'a mut self) -> ValuesMut<'a, K, V>

Source

impl<'a, K: 'a + Hash + Eq, V: 'a> MapIterMut<'a> for HashMap<K, V>

Source

type ValueMut = &'a mut V

Source

type IterValuesMut = ValuesMut<'a, K, V>

Source

fn values_mut(&'a mut self) -> ValuesMut<'a, K, V>

Implementors