pub trait HasData {
type Item;
}Expand description
A trait for iterable collections which contain data of a given type.
In most cases, you shouldn’t implement this trait directly; instead, you should implement
IntoIterator, which will in turn implement this trait.
The only exception is dynamically-sized types, which cannot implement IntoIterator. Instead,
you should implement this trait to indicate what type of data is inside the collection.