pub trait MapIterMut<'a>: MapIter<'a> + IterMut<'a> {
type ValueMut: RefMut<'a, Self::Value>;
type IterValuesMut: Iterator<Item = Self::ValueMut>;
// Required method
fn values_mut(&'a mut self) -> Self::IterValuesMut;
}Expand description
A trait for map-like collections which can be iterated by references to keys, and mutable references to values.
Required Associated Types
Sourcetype ValueMut: RefMut<'a, Self::Value>
type ValueMut: RefMut<'a, Self::Value>
Type of the mutable references to the values in the collection.
For more information, see the ValueRefMut trait.
Sourcetype IterValuesMut: Iterator<Item = Self::ValueMut>
type IterValuesMut: Iterator<Item = Self::ValueMut>
Type of the iterator over mutable references to values.
Required Methods
Sourcefn values_mut(&'a mut self) -> Self::IterValuesMut
fn values_mut(&'a mut self) -> Self::IterValuesMut
Constructs an iterator over mutable references to the values in this collection.